<?php

namespace Drupal\menu_migration;

use Drupal\Core\Entity\EntityInterface;
use Drupal\menu_migration\Entity\ImportTypeInterface;

/**
 * Defines a class to build a listing of import type entities.
 *
 * @see \Drupal\menu_migration\Entity\ImportType
 */
class ImportTypeListBuilder extends ImportExportListBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('ID');
    $header['label'] = $this->t('Name');
    $header['source'] = $this->t('Source');
    $header['format'] = $this->t('Format');
    $header['menus'] = $this->t('Menus');
    $header['command'] = $this->t('Drush command');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface|ImportTypeInterface $entity) {
    $source = $entity->getSourcePlugin();
    $row['id'] = $entity->id();
    $row['label'] = $entity->label();
    $row['source'] = $source ? $source->label() : '';
    $row['format'] = $source && $source->getFormatPlugin() ? $source->getFormatPlugin()->label() : '';
    $row['menus'] = implode(', ', $entity->getMenus());
    $row['command'] = $this->getFormattedEntityCommand($entity);
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $import = [
      'title' => $this->t('Import'),
      'weight' => -50,
      'url' => $this->ensureDestination($entity->toUrl('import-form')),
    ];

    return ['import' => $import] + parent::getDefaultOperations($entity);
  }

}
